@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20211130';
+our $VERSION = '0.20211228';
 
-# Table last modified: 2021-11-30
+# Table last modified: 2021-12-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,12 +103,12 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|5[0-2458]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|6[05689]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|6[05689]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|3[0-589]|5[18]|7[014-9])|3(?:65|1[0-3579]|7[07-9]|2[458]|8[013689]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|1[035689]|0[124-8]|8[168]|4[02-489]|2[0-469]|6[08])|2(?:40|71|6[26]|1[0-258]|3[38]|0[568]|8[0-589]|5[0-24-8])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[01356]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|7[014-689]|3[0-589]|5[18])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|5[06]|8[05]|7[08]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|5[013-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
@@ -133,7 +133,7 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|1[014-9]|7[08]|5[059])|3(?:[25]0|8[3-57]|0[13]|7[05]|6[023]|3[01]|1[0-28])|1(?:21|45|50|1[0-58]|0[89]|3[0479]|8[01])|7(?:3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|5[128]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|1[1256])|6(?:01|7[02578]|4[04]|3[0147]|6[013689]|2[13568]|5[03-68]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|5[128]|8[0346]|7[1-36]|6[0367]|2[1-3569]|0[235-9]|1[1256])|6(?:01|4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:1[1-689]|2[0-6])|2(?:14|60|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
@@ -283,7 +283,7 @@ our %ZIP_TABLE = (
     '307' => '(?:8[56]01)',
     '308' => '(?:(?:8(?:5(?:[45]0|2[1-4]|1[0-3])|6(?:[03]8|16))|019[34]))',
     '309' => '(?:1(?:29[2-7]|79[237]|19[25]|698))',
-    '310' => '(?:8(?:5(?:[47]0|36|67|0[1258]|8[1568]|5[0158]|2[05]|1[12])|6(?:22|39|41|86|1[06]|7[17]|0[124]|6[68])|282))',
+    '310' => '(?:8(?:5(?:[47]0|36|67|0[12589]|8[1568]|5[0158]|2[05]|1[12])|6(?:22|39|41|86|1[06]|7[17]|0[124]|6[68])|282))',
     '311' => '(?:(?:3(?:8(?:80|9[2-4])|19[2-57]|49[2-478])|1(?:39[23]|49[23]|59[23]|792)|4(?:19[3-68]|39[1-3]|59[25])|249[235]|019[23]))',
     '312' => '(?:85(?:0[1-578]|1[01]))',
     '313' => '(?:8(?:6(?:[68]6|11)|511))',
@@ -364,7 +364,7 @@ our %ZIP_TABLE = (
     '388' => '(?:85(?:11|22|55))',
     '389' => '(?:(?:0(?:6(?:8[128]|9[235-8])|19[2-8]|29[23568]|89[2378]|59[238])|1(?:19[256]|293|392)|2(?:[1357]92|29[28])))',
     '390' => '(?:(?:8(?:5(?:85|0[1-35-8]|4[013]|1[0158]|3[01359]|[56][05]|2[035])|6(?:48|86|2[013]|3[09]|1[01]|0[1-35])|7(?:65|0[237]|1[0-24]))|1(?:1(?:9[378]|8[1-35-9])|29[358]|39[2-4]|[457]92)))',
-    '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[15])|0(?:29[2-7]|39[2-6]|192)))',
+    '391' => '(?:(?:85(?:31|40|0[13]|5[058]|6[0167]|1[0-2]|8[08]|2[125])|0(?:29[2-7]|39[2-6]|192)))',
     '392' => '(?:8(?:5(?:[58]5|20|7[78]|0[25]|4[089]|1[01])|6(?:86|2[78]|0[19]|1[01])))',
     '393' => '(?:8(?:5(?:[58]5|11|0[1-3])|601))',
     '394' => '(?:8(?:5(?:[24]0|77|1[0-25]|8[58]|5[05])|6(?:11|65|86)))',
@@ -537,7 +537,7 @@ our %ZIP_TABLE = (
     '566' => '(?:8(?:5(?:[58]5|01|13|66)|686))',
     '567' => '(?:8(?:5(?:[34]0|[56]7|1[015]|2[0135]|8[58]|7[08]|0[1257])|6(?:51|80)))',
     '569' => '(?:(?:8(?:5(?:33|49|0[135]|5[158]|2[02]|8[58]|7[0157]|6[679]|1[0-2])|6(?:60|86))|1(?:19[2-7]|09[24-68])))',
-    '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)))',
+    '570' => '(?:8(?:5(?:39|40|0[167]|[58][58]|1[15])|6(?:34|66)|787))',
     '571' => '(?:8(?:5(?:[45]5|33|67|71|8[05]|0[2-47])|6(?:33|40|86)))',
     '572' => '(?:85(?:40|8[01589]|0[158]|2[28]|3[013]|7[02]|5[0158]|6[67]|1[01]))',
     '573' => '(?:(?:8(?:5(?:34|56|67|73|88|0[58]|1[01])|666)|10(?:[34]0|1[03]|0[1478])|019[356]))',
@@ -633,7 +633,7 @@ our %ZIP_TABLE = (
     '667' => '(?:(?:8(?:555|651)|0198))',
     '668' => '(?:(?:8(?:6(?:66|5[05])|501)|0(?:29[238]|393)))',
     '669' => '(?:(?:3(?:39[24-6]|19[28]|69[23]|495|892)|5(?:19[2378]|39[258]|292)|6(?:[2578]92|19[25])|2(?:[12]92|397)|159[25]|4[13]92))',
-    '670' => '(?:8(?:5(?:43|3[03]|2[04]|7[057]|8[058]|0[1-356]|6[67]|5[0458]|1[017])|6(?:5[25]|6[068]|7[57]|8[029])))',
+    '670' => '(?:8(?:5(?:3[03]|2[04]|4[34]|7[057]|8[058]|0[1-356]|6[67]|5[0458]|1[017])|6(?:5[25]|6[068]|7[57]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:19[238]|59[358]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
     '673' => '(?:(?:8(?:5(?:[01]1|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
@@ -770,7 +770,7 @@ our %ZIP_TABLE = (
     '809' => '(?:8501)',
     '810' => '(?:8(?:5(?:3[0-357-9]|1[1-9]|5[135-8]|7[01578]|2[0-578]|0[1-46-9]|8[13-57-9]|4[013-6]|6[0135-8])|6(?:8[035689]|4[28]|6[02-79]|7[03-7]|1[0179]|0[13-9]|2[0-2579]|5[0-6]|3[1346-9])|7(?:98|2[0-257]|3[14]|0[157]|1[06-8])))',
     '811' => '(?:(?:2(?:29[2-578]|19[2-6]|39[258]|49[256]|592)|3(?:19[23578]|29[3568]|492|598)|4(?:19[2358]|39[23]|292)|0(?:19[2-7]|295)|1(?:39[2-6]|292)|5192))',
-    '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|2[0-24-689]|7[025-8]|5[0-79]|[14][0-8]|6[0-25689])|5(?:[23578]\d|0[1-9]|6[0-689]|[14][0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
+    '812' => '(?:(?:8(?:6(?:8[0134679]|3\d|0[1-9]|2[0-24-689]|7[025-8]|5[0-79]|[14][0-8]|6[0-25689])|5(?:[1-3578]\d|0[1-9]|6[0-689]|4[0-8])|7(?:35|0[5-9]|1[78]|9[24]))|95(?:[24]0|11|8[89]|0[235]|5[12])))',
     '813' => '(?:8(?:5(?:29|33|55|68|1[39]|7[78]|0[13]|8[58])|6(?:09|2[36]|8[01])))',
     '814' => '(?:(?:8(?:5(?:77|0[135]|2[025]|6[57]|8[589]|1[0-2]|5[03-6])|6(?:02|51)|798)|01(?:80|9[238])))',
     '815' => '(?:8(?:5(?:33|88|4[06]|0[13]|2[09]|5[05]|1[01])|6(?:[68]6|01)))',
@@ -937,7 +937,7 @@ our %ZIP_TABLE = (
     '980' => '(?:(?:8(?:4(?:7[78]|[04][1-35-8]|8[014-8]|2[0-369]|1[0145]|3[013569]|5[02-468]|6[016])|5(?:[15][015]|3[134]|4[3-6]|7\d|2[01569]|0[158]|6[0156]|8[013578])|6(?:40|86|5[0-26]|6[018]|0[1258]|3[1-36-9]|2[12]|7[017])|7(?:11|33|77|0[137]|9[2-578]))|6(?:0(?:55|88)|1(?:61|80))))',
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
-    '983' => '(?:8(?:5(?:70|85|0[1247]|6[057]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
+    '983' => '(?:8(?:5(?:70|85|6[0257]|0[1247]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
     '984' => '(?:8(?:5(?:0[135]|8[045]|7[057]|2[25]|6[0178]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:77|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
